@@ -74,9 +74,7 @@ def get_system_prompt(abilities, bot_setting):
         "system": system,
         "cd_prompt": cd_prompt,
         "abilities_str": abilities_str,
-        "programmer_mode": False,
         "no_exit_if_incomplete": False,
-        "allow_read_file": False,
         "allow_read_multiple_files": False,
         "allow_execute_command": False,
         "allow_write_or_overwrite_file": False,
@@ -84,6 +82,7 @@ def get_system_prompt(abilities, bot_setting):
         "allow_search_files": False,
         "allow_list_files": False,
         "allow_access_webpage": False,
+        "programmer_mode": bot_setting["programmerMode"],
     }
 
     context.update(bot_setting["systemAbility"])
@@ -242,4 +241,3 @@ def format_filelist_str(items, limit):
 def get_formatted_filelist_str(root: str, recursive: bool, limit=200):
     items = get_files_and_folders(root, recursive)
     return format_filelist_str(items, limit=limit)
-
