@@ -6,7 +6,6 @@ import inspect
 import asyncio
 import nest_asyncio
 
-# 应用 nest_asyncio 补丁，以允许在已经运行的事件循环中再次运行事件循环
 nest_asyncio.apply() 
 
 def call_func(func, args=None, kwargs=None):
@@ -17,19 +16,30 @@ def call_func(func, args=None, kwargs=None):
 
     if inspect.isgeneratorfunction(func):
         return list(func(*args, **kwargs))
+    elif inspect.isasyncgenfunction(func):
+        async def collect_async_gen():
+            return [item async for item in func(*args, **kwargs)]
+        
+        try:
+            loop = asyncio.get_running_loop()
+        except RuntimeError:
+            return asyncio.run(collect_async_gen())
+        else:
+            async def run_async_gen():
+                return await collect_async_gen()
+            future = asyncio.ensure_future(run_async_gen())
+            while not future.done():
+                loop.run_until_complete(asyncio.sleep(0.1))  # 避免阻塞
+            return future.result()
     elif inspect.iscoroutinefunction(func):
         coro = func(*args, **kwargs) if inspect.iscoroutinefunction(func) else func
         try:
-            # 尝试获取当前运行的事件循环
             loop = asyncio.get_running_loop()
         except RuntimeError:
-            # 如果没有运行的事件循环，使用 asyncio.run()
             return asyncio.run(coro)
         else:
-            # 如果事件循环已经在运行，直接调度协程并等待结果
             async def run_coro():
                 return await coro
-            # 在当前事件循环中调度任务并等待完成
             future = asyncio.ensure_future(run_coro())
             while not future.done():
                 loop.run_until_complete(asyncio.sleep(0.1))  # 避免阻塞
@@ -96,7 +106,7 @@ def wrapped_func(func, module_path):
                 print(f"调用 {func.__name__} 时发生错误: {str(e)}")
                 raise
         
-        print(f"{func.__name__} 调用完毕,结果为:", result)
+        print(f"{func.__name__} 调用完毕")
 
         return result
     
